@@ -26,13 +26,19 @@ class Interface:
 
         self.monitor_killer = False
 
-        self.have_adapter = self.adapter_check()
-
-        if self.have_adapter:
-            self.start_event_monitor()
+        self.adapter_check()
+        self.start_event_monitor()
 
     def adapter_check(self):
-        res = subprocess.check_output(RFKILL_CHK).decode('utf-8')
+        proc = subprocess.run(RFKILL_CHK, stdout=subprocess.PIPE)
+        if proc.returncode != 0:
+            self.debug("Error running command: %s." % RFKILL_CHK)
+            res = ""
+        else:
+            res = proc.stdout.decode('utf-8')
+
+        match = None
+        have_adapter = False
 
         '''
         Assume the output of:
@@ -45,22 +51,19 @@ class Interface:
             Soft blocked: yes
             Hard blocked: no
         '''
+        if res:
+            match = re.search(r'^(?P<idx>\d+): .+: Bluetooth\n', res)
 
-        self.debug("adapter_check full output:\n%s" % res)
-
-        if not res:
+        if match:
+            self.debug("adapter_check full output:\n%s" % res)
+            self.adapter_index = int(match.group('idx'))
+            self.debug("adapter_check found adapter at %d" % self.adapter_index)
+            have_adapter = True
+        else:
             self.debug("adapter_check no output (no adapter)")
-            self.have_adapter = False
-            return False
 
-        reslines = res.split('\n')
-        for line in reslines:
-            if "Bluetooth" in line:
-                self.adapter_index = int(line[0])
-                self.debug("adapter_check found adapter at %d" % self.adapter_index)
-                return True
-
-        return False
+        self.have_adapter = have_adapter
+        return have_adapter
 
     def start_event_monitor(self):
         if not self.tproc and not self.monitor_killer:
@@ -72,9 +75,6 @@ class Interface:
             l = self.tproc.stdout.readline().decode('utf-8') # This blocks until it receives a newline.
             self.update_state(l)
 
-        self.tproc = None
-        thread.exit()
-
     def update_state(self, line):
         self.debug("update_state line: %s" % line)
 
@@ -95,15 +95,17 @@ class Interface:
         2017-12-08 11:54:16,972431-0800: idx 1 type 1 op 0 soft 0 hard 0
         2017-12-08 11:54:16,972474-0800: idx 4 type 2 op 0 soft 0 hard 0
         '''
+        if not self.have_adapter:
+            self.adapter_check()
 
-        match = re.search(r'idx (?P<idx>\d+) type (?P<type>\d+) op (?P<op>\d+) soft (?P<soft>\d+) hard (?P<hard>\d+)', line)
-
-        if not match:
-            return
-
-        if int(match.group('idx')) == self.adapter_index:
-            self.soft_block = int(match.group('soft')) == 1
-            self.hard_block = int(match.group('hard')) == 1
+        if self.have_adapter:
+            match = re.search(r'idx (?P<idx>\d+) type (?P<type>\d+) op (?P<op>\d+) soft (?P<soft>\d+) hard (?P<hard>\d+)', line)
+            if match:
+                if int(match.group('idx')) == self.adapter_index:
+                    if int(match.group('op')) == 1:
+                        self.adapter_check()
+                    self.soft_block = int(match.group('soft')) == 1
+                    self.hard_block = int(match.group('hard')) == 1
 
         self.update_ui()
 
